summaryrefslogtreecommitdiff
path: root/matching/include
diff options
context:
space:
mode:
authorArnur Nigmetov <nigmetov@tugraz.at>2020-02-18 18:48:26 +0100
committerArnur Nigmetov <nigmetov@tugraz.at>2020-02-18 18:48:44 +0100
commitdfb161cb17a546329921ce27e1d9c4fa93e2a506 (patch)
tree3253fc889cd5d394dbae9a49f2d408fbfc6f1694 /matching/include
parentb9cad937b5a0c6d27c88b5102e123d350938afe2 (diff)
Rename enum.
Diffstat (limited to 'matching/include')
-rw-r--r--matching/include/bifiltration.h6
-rw-r--r--matching/include/matching_distance.h4
-rw-r--r--matching/include/simplex.h4
3 files changed, 6 insertions, 8 deletions
diff --git a/matching/include/matching_distance.h b/matching/include/matching_distance.h
index 72743a4..bb1dfea 100644
--- a/matching/include/matching_distance.h
+++ b/matching/include/matching_distance.h
@@ -77,13 +77,11 @@ namespace md {
#endif
};
+
template<class DiagramProvider>
class DistanceCalculator {
-// using DiagramProvider = md::Bifiltration;
-// using DiagramProvider = md::ModulePresentation;
using DualBox = md::DualBox;
-
using CellValueVector = std::vector<CellWithValue>;
public:
diff --git a/matching/include/simplex.h b/matching/include/simplex.h
index e0a654b..e9d0e30 100644
--- a/matching/include/simplex.h
+++ b/matching/include/simplex.h
@@ -12,7 +12,7 @@ namespace md {
class Bifiltration;
enum class BifiltrationFormat {
- rene, rivet
+ phat_like, rivet
};
class AbstractSimplex {
@@ -85,7 +85,7 @@ namespace md {
void init_rivet(std::string s);
- void init_rene(std::string s);
+ void init_phat_like(std::string s);
Index id() const { return id_; }
diff --git a/matching/include/bifiltration.h b/matching/include/bifiltration.h
index 2b4950f..bdb7a4e 100644
--- a/matching/include/bifiltration.h
+++ b/matching/include/bifiltration.h
@@ -85,12 +85,12 @@ namespace md {
void rivet_format_reader(std::ifstream&);
- void rene_format_reader(std::ifstream&);
+ void phat_like_format_reader(std::ifstream&);
// in Rene format each simplex knows IDs of its boundary facets
// postprocess_rene_format fills vector of IDs of boundary facets
// in each simplex
- void postprocess_rene_format();
+ void postprocess_phat_like_format();
// in Rivet format each simplex knows its vertices,
// postprocess_rivet_format fills vector of IDs of boundary facets
@@ -85,12 +85,12 @@ namespace md {
// in Rene format each simplex knows IDs of its boundary facets
- // postprocess_rene_format fills vector of IDs of boundary facets
+ // postprocess_phat_like_format fills vector of IDs of boundary facets
// in each simplex